/*  -- translated by f2c (version 20100827).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     COORDINATE TRANSFORMATION (2D POLAR -> CARTESIAN ) */
/*                                              93/02/18   S.SAKAI */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int ct2pc_(real *r__, real *theta, real *x, real *y)
{
    /* Builtin functions */
    double cos(doublereal), sin(doublereal);

    *x = *r__ * cos(*theta);
    *y = *r__ * sin(*theta);
    return 0;
} /* ct2pc_ */

